NativebrikDispatcher class
NativebrikDispatcher is the main dispatcher for the Nativebrik SDK.
reference: https://docs.nativebrik.com/reference/flutter/nativebrikdispatcher
Usage:
NativebrikDispatcher.instance.dispatch(NativebrikEvent('event_name'));
Constructors
- NativebrikDispatcher()
-
Creates a new instance of NativebrikDispatcher.
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
dispatch(
NativebrikEvent event) → Future< void> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- instance → NativebrikDispatcher
-
The singleton instance of NativebrikDispatcher.
no setter